Products

1. General Motors trademarks and indicia are used under license to David Carey, Inc.

2. Ford Oval and nameplates are registered trademarks of Ford Motor Company used under license to David Carey, Inc.

3. Carroll Shelby and Carroll Shelby Licensing, Inc. registered trademarks and/or trade dress used under license to David Carey, Inc.

4. Mopar, Dodge, Jeep, Hemi, Plymouth, Ram and Chrysler vehicle images, and logos are trademarks of FCA US, LLC used under license to David Carey, Inc. © FCA US LLC 2015.

### LICENSED CAMP SHIRTS

- Chevrolet
- Corvette C1-C6
- Ford
- Mopar
- Pontiac
- Shelby
- Buick
- Oldsmobile

### LICENSED T-SHIRTS

- Chrysler/Plymouth
- Dodge
- Ford
- Mopar
- Ram
- Shelby

### LICENSED Outerwear

- Chrysler/Plymouth
- Dodge
- Ford
- Mopar
- Ram
- Shelby

### STOCK CAMP DESIGNS

- Alaska
- Animals
- Cities
- Drinks
- Fiery Foods
- Music
- Sports & Hobbies
- SW/Chile Pepper
- Nautical/Lighthouses
- Transportation
- Winery

### Categories

- Animal Ties
- David Carey Originals
- Licensed Outerwear
- Licensed Scarves
- Lounge Pants
- Outerwear
- Scarves
- Shirts
- Shirts > Licensed Shirts > Buick
- Shirts>Licensed T-shirts>Mopar
- Ties
- Special Deals
- LOGO WEAR

Logo

### Top Sellers

Ford Model A Camp Shirt
$55.00 - $57.00
Details
View All Top Sellers